﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.IO;
using System.Net;
using System.Text.RegularExpressions;
using System.Xml;

public partial class htmlWidgetManager : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        string templatePath = Request.PhysicalApplicationPath + "template/template.html";
        
        Response.Write(GetAlertHtml(templatePath));
    }

    private string GetAlertHtml(string templatePath)
    {
        string html = string.Empty;
        XmlNodeList items = LoadXml();

        foreach (XmlNode item in items)
        {
            string description = item["description"].InnerText;
            StringDictionary linkDescription = SplitDescription(description);

            string message = linkDescription["description"];
            string image = linkDescription["image"];
            string title = item["title"].InnerText;
            string link = item["link"].InnerText;
            string aalink = "http://www.amberalert.sk";

            Template template = new Template(templatePath);
            StringDictionary tags = new StringDictionary();
            tags["title"] = title;
            tags["message"] = message;
            tags["image"] = image;
            tags["link"] = link;
            tags["aalink"] = aalink;
            tags["info"] = "Videli ste toto dieťa? VOLAJTE 158";
            template.ReplaceTags(tags);

            html += template.ToString();
        }

        return html;
    }

    private XmlNodeList LoadXml()
    {
        WebRequest request = WebRequest.Create("http://rss.amberalert.eu/sk/alert/sk/index.rss");
        WebResponse response = request.GetResponse();

        Stream rssStream = response.GetResponseStream();
        XmlDocument xmlDoc = new XmlDocument();
        xmlDoc.Load(rssStream);

        return xmlDoc.SelectNodes("rss/channel/item");
    }

    private StringDictionary SplitDescription(string description)
    {
        StringDictionary aDescription = new StringDictionary();
        Regex regImages = new Regex(@"<img[^>]+src=""([^""]+)""[^>]+>");
        Regex regSrc = new Regex(@"(?<=img+.+src\=[\x27\x22])(?<Url>[^\x27\x22]*)(?=[\x27\x22])");
        string image = regImages.Match(description).ToString();
        MatchCollection src = regSrc.Matches(image);
        aDescription["image"] = src[0].ToString();
        aDescription["description"] = description.Replace(image, string.Empty);

        return aDescription;
    }

    public class Template
    {
        private string data;

        public Template(string template)
        {
            if (File.Exists(template))
            {
                StreamReader streamReader = File.OpenText(template);
                data = streamReader.ReadToEnd();
            }
            else
            {
                throw new Exception("Template file not found.");
            }
        }

        public void ReplaceTags(StringDictionary tags)
        {
            if (tags.Count > 0)
            {
                foreach (DictionaryEntry tag in tags)
                {
                    data = data.Replace("{" + tag.Key + "}", tag.Value.ToString());
                }
            }
            else
            {
                throw new Exception("No tags designated for replacement.");
            }
        }

        public new string ToString()
        {
            return data;
        }
    }
}